This library is used to communicate with configuration registers, status registers, AXI4-Stream and BRAM interfaces on Digilent USB104 A7 and Red Pitaya STEMlab boards:

https://pavel-demin.github.io/usb104-a7-notes

https://pavel-demin.github.io/red-pitaya-notes

This library uses the [python-libusb1](https://github.com/vpelletier/python-libusb1) library to communicate via the USB interface with the AXI4-Stream USB and AXI4-Stream hub modules on the Digilent USB104 A7 board:

https://pavel-demin.github.io/usb104-a7-notes/usb-interface

This library uses the [socket](https://docs.python.org/3/library/socket.html) library to communicate via the Ethernet interface with the AXI4 hub module on the Red Pitaya STEMlab board:

https://pavel-demin.github.io/red-pitaya-notes/axi-hub
